==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fi/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Mukautetut kentät',
    'field'		                => 'Kenttä',
    'about_fieldsets_title'		=> 'Tietoja kenttäsarjoista',
    'about_fieldsets_text'		=> 'Kentäsarjoilla voit luoda ryhmiä mukautetuista kentistä, joita tarvitaan tietyillä laitemalleilla.',
    'custom_format'             => 'Mukautettu muoto ...',
    'encrypt_field'      	        => 'Salaa tämän kentän arvo tietokannassa',
    'encrypt_field_help'      => 'VAROITUS: Kentän salaaminen estää kentän arvolla hakemisen.',
    'encrypted'      	        => 'Salattu',
    'fieldset'      	        => 'Kenttäsarja',
    'qty_fields'      	      => 'Kenttien määrä',
    'fieldsets'      	        => 'Kenttäsarjat',
    'fieldset_name'           => 'Kenttäsarjan nimi',
    'field_name'              => 'Kentän nimi',
    'field_values'            => 'Kentän arvot',
    'field_values_help'       => 'Lisää vaihtoehtoehtoja yksi per rivi. Muut tyhjät rivit, paitsi ensimmäinen, jätetään huomiotta.',
    'field_element'           => 'Lomakkeen elementti',
    'field_element_short'     => 'Elementti',
    'field_format'            => 'Muoto',
    'field_custom_format'     => 'Mukautettu regex-muoto',
    'field_custom_format_help'     => 'Tämän kentän avulla voit käyttää regex-lauseketta validointiin. Sen pitäisi alkaa "regex:" - esimerkiksi vahvistaaksesi, että mukautetun kentän arvo sisältää voimassa olevan IMEI: n (15 numeerista numeroa), käyttäisit <code>regex: /^[0-9]{15}$/</code>.',
    'required'   		          => 'Vaadittu',
    'req'   		              => 'Vaad.',
    'used_by_models'   		    => 'Käytetään malleissa',
    'order'   		            => 'Tilata',
    'create_fieldset'         => 'Uusi kenttäsarja',
    'create_field'            => 'Uusi mukautettu kenttä',
    'value_encrypted'      	        => 'Kentän arvo salataan tietokannassa. Vain järjestelmänvalvojat voivat tarkastella purettua arvoa',
    'show_in_email'     => 'Käytetäänkö kentän arvoa käyttäjälle lähetettävissä luovutus-sähköposteissa? Salattuja kenttiä ei voi lisätä sähköposteihin.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fi/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Mukautetut kentät',
    'manage'                    => 'Manage',
    'field'		                => 'Kenttä',
    'about_fieldsets_title'		=> 'Tietoja kenttäsarjoista',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Salaa tämän kentän arvo tietokannassa',
    'encrypt_field_help'      => 'VAROITUS: Kentän salaaminen estää kentän arvolla hakemisen.',
    'encrypted'      	        => 'Salattu',
    'fieldset'      	        => 'Kenttäsarja',
    'qty_fields'      	      => 'Kenttien määrä',
    'fieldsets'      	        => 'Kenttäsarjat',
    'fieldset_name'           => 'Kenttäsarjan nimi',
    'field_name'              => 'Kentän nimi',
    'field_values'            => 'Kentän arvot',
    'field_values_help'       => 'Lisää vaihtoehtoehtoja yksi per rivi. Muut tyhjät rivit, paitsi ensimmäinen, jätetään huomiotta.',
    'field_element'           => 'Lomakkeen elementti',
    'field_element_short'     => 'Elementti',
    'field_format'            => 'Muoto',
    'field_custom_format'     => 'Mukautettu regex-muoto',
    'field_custom_format_help'     => 'Tämän kentän avulla voit käyttää regex-lauseketta validointiin. Sen pitäisi alkaa "regex:" - esimerkiksi vahvistaaksesi, että mukautetun kentän arvo sisältää voimassa olevan IMEI: n (15 numeerista numeroa), käyttäisit <code>regex: /^[0-9]{15}$/</code>.',
    'required'   		          => 'Vaadittu',
    'req'   		              => 'Vaad.',
    'used_by_models'   		    => 'Käytetään malleissa',
    'order'   		            => 'Tilata',
    'create_fieldset'         => 'Uusi kenttäsarja',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Uusi mukautettu kenttä',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Kentän arvo salataan tietokannassa. Vain järjestelmänvalvojat voivat tarkastella purettua arvoa',
    'show_in_email'     => 'Käytetäänkö kentän arvoa käyttäjälle lähetettävissä luovutus-sähköposteissa? Salattuja kenttiä ei voi lisätä sähköposteihin.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
